@@ -10,7 +10,7 @@
 #   IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 #   WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #
-#   $Id: epchar.c,v 1.21 2005/08/07 00:02:58 richter Exp $
+#   $Id: epchar.c 331953 2005-11-09 05:11:19Z richter $
 #
 ###################################################################################*/
 
@@ -288,6 +288,535 @@ struct tCharTrans Char2Html [] =
         { '' ,   "&thorn;"  },    /* 	Small thorn, Icelandic  */
         { '\255', "&yuml;"   },    /* 	Small y, diresis / umlaut  */
     } ; 
+
+
+
+struct tCharTrans Char2HtmlMin [] = 
+
+    {
+        { ' ' ,   ""         },    /* &#00;		Unused */ 
+        { ' ' ,   ""         },    /* &#01;		Unused */
+        { ' ' ,   ""         },    /* &#02;		Unused  */
+        { ' ' ,   ""         },    /* &#03;		Unused  */
+        { ' ' ,   ""         },    /* &#04;		Unused  */
+        { ' ' ,   ""         },    /* &#05;		Unused  */
+        { ' ' ,   ""         },    /* &#06;		Unused  */
+        { ' ' ,   ""         },    /* &#07;		Unused  */
+        { ' ' ,   ""         },    /* &#08;		Unused  */
+        { ' ' ,   ""         },    /* &#09;		Horizontal tab  */
+        { ' ' ,   ""         },    /* &#10;		Line feed  */
+        { ' ' ,   ""         },    /* &#11;		Unused  */
+        { ' ' ,   ""         },    /* &#12;		Unused  */
+        { ' ' ,   ""         },    /* &#13;		Carriage Return  */
+        { ' ' ,   ""         },    /* &#14;		Unused  */
+        { ' ' ,   ""         },    /* &#15;		Unused  */
+        { ' ' ,   ""         },    /* &#16;		Unused  */
+        { ' ' ,   ""         },    /* &#17;		Unused  */
+        { ' ' ,   ""         },    /* &#18;		Unused  */
+        { ' ' ,   ""         },    /* &#19;		Unused  */
+        { ' ' ,   ""         },    /* &#20;		Unused  */
+        { ' ' ,   ""         },    /* &#21;		Unused  */
+        { ' ' ,   ""         },    /* &#22;		Unused  */
+        { ' ' ,   ""         },    /* &#23;		Unused  */
+        { ' ' ,   ""         },    /* &#24;		Unused  */
+        { ' ' ,   ""         },    /* &#25;		Unused  */
+        { ' ' ,   ""         },    /* &#26;		Unused  */
+        { ' ' ,   ""         },    /* &#27;		Unused  */
+        { ' ' ,   ""         },    /* &#28;		Unused  */
+        { ' ' ,   ""         },    /* &#29;		Unused  */
+        { ' ' ,   ""         },    /* &#30;		Unused  */
+        { ' ' ,   ""         },    /* &#31;		Unused  */
+        { ' ' ,   ""         },    /* 	&#32;		Space  */
+        { '!' ,   ""         },    /* 	&#33;		Exclamation mark  */
+        { '"' ,   "&quot;"   },    /* 	Quotation mark  */
+        { '#' ,   ""         },    /* 	&#35;		Number sign  */
+        { '$' ,   ""         },    /* 	&#36;		Dollar sign  */
+        { '%' ,   ""         },    /* 	&#37;		Percent sign  */
+        { '&' ,   "&amp;"    },    /* 	Ampersand  */
+        { '\'' ,  ""         },    /* 	&#39;		Apostrophe  */
+        { '(' ,   ""         },    /* 	&#40;		Left parenthesis  */
+        { ')' ,   ""         },    /* 	&#41;		Right parenthesis  */
+        { '*' ,   ""         },    /* 	&#42;		Asterisk  */
+        { '+' ,   ""         },    /* 	&#43;		Plus sign  */
+        { ',' ,   ""         },    /* 	&#44;		Comma  */
+        { '-' ,   ""         },    /* 	&#45;		Hyphen  */
+        { '.' ,   ""         },    /* 	&#46;		Period (fullstop)  */
+        { '/' ,   ""         },    /* 	&#47;		Solidus (slash)  */
+        { '0' ,   ""         },    /* 	&#48;		Digit 0  */
+        { '1' ,   ""         },    /* 	&#49;		Digit 1  */
+        { '2' ,   ""         },    /* 	&#50;		Digit 2  */
+        { '3' ,   ""         },    /* 	&#51;		Digit 3  */
+        { '4' ,   ""         },    /* 	&#52;		Digit 4  */
+        { '5' ,   ""         },    /* 	&#53;		Digit 5  */
+        { '6' ,   ""         },    /* 	&#54;		Digit 6  */
+        { '7' ,   ""         },    /* 	&#55;		Digit 7  */
+        { '8' ,   ""         },    /* 	&#56;		Digit 8  */
+        { '9' ,   ""         },    /* 	&#57;		Digit 9  */
+        { ':' ,   ""         },    /* 	&#58;		Colon  */
+        { ';' ,   ""         },    /* 	&#59;		Semicolon  */
+        { '<' ,   "&lt;"     },    /* 	Less than  */
+        { '=' ,   ""         },    /* 	&#61;		Equals sign  */
+        { '>' ,   "&gt;"     },    /* 	Greater than  */
+        { '?' ,   ""         },    /* 	&#63;		Question mark  */
+        { '@' ,   ""         },    /* 	&#64;		Commercial at  */
+        { 'A' ,   ""         },    /* 	&#65;		Capital A  */
+        { 'B' ,   ""         },    /* 	&#66;		Capital B  */
+        { 'C' ,   ""         },    /* 	&#67;		Capital C  */
+        { 'D' ,   ""         },    /* 	&#68;		Capital D  */
+        { 'E' ,   ""         },    /* 	&#69;		Capital E  */
+        { 'F' ,   ""         },    /* 	&#70;		Capital F  */
+        { 'G' ,   ""         },    /* 	&#71;		Capital G  */
+        { 'H' ,   ""         },    /* 	&#72;		Capital H  */
+        { 'I' ,   ""         },    /* 	&#73;		Capital I  */
+        { 'J' ,   ""         },    /* 	&#74;		Capital J  */
+        { 'K' ,   ""         },    /* 	&#75;		Capital K  */
+        { 'L' ,   ""         },    /* 	&#76;		Capital L  */
+        { 'M' ,   ""         },    /* 	&#77;		Capital M  */
+        { 'N' ,   ""         },    /* 	&#78;		Capital N  */
+        { 'O' ,   ""         },    /* 	&#79;		Capital O  */
+        { 'P' ,   ""         },    /* 	&#80;		Capital P  */
+        { 'Q' ,   ""         },    /* 	&#81;		Capital Q  */
+        { 'R' ,   ""         },    /* 	&#82;		Capital R  */
+        { 'S' ,   ""         },    /* 	&#83;		Capital S  */
+        { 'T' ,   ""         },    /* 	&#84;		Capital T  */
+        { 'U' ,   ""         },    /* 	&#85;		Capital U  */
+        { 'V' ,   ""         },    /* 	&#86;		Capital V  */
+        { 'W' ,   ""         },    /* 	&#87;		Capital W  */
+        { 'X' ,   ""         },    /* 	&#88;		Capital X  */
+        { 'Y' ,   ""         },    /* 	&#89;		Capital Y  */
+        { 'Z' ,   ""         },    /* 	&#90;		Capital Z  */
+        { '[' ,   ""         },    /* 	&#91;		Left square bracket  */
+        { '\\' ,  ""         },    /* 	&#92;		Reverse solidus (backslash)  */
+        { ']' ,   ""         },    /* 	&#93;		Right square bracket  */
+        { '^' ,   ""         },    /* 	&#94;		Caret  */
+        { '_' ,   ""         },    /* 	&#95;		Horizontal bar (underscore)  */
+        { '`' ,   ""         },    /* 	&#96;		Acute accent  */
+        { 'a' ,   ""         },    /* 	&#97;		Small a  */
+        { 'b' ,   ""         },    /* 	&#98;		Small b  */
+        { 'c' ,   ""         },    /* 	&#99;		Small c  */
+        { 'd' ,   ""         },    /* 	&#100;		Small d  */
+        { 'e' ,   ""         },    /* 	&#101;		Small e  */
+        { 'f' ,   ""         },    /* 	&#102;		Small f  */
+        { 'g' ,   ""         },    /* 	&#103;		Small g  */
+        { 'h' ,   ""         },    /* 	&#104;		Small h  */
+        { 'i' ,   ""         },    /* 	&#105;		Small i  */
+        { 'j' ,   ""         },    /* 	&#106;		Small j  */
+        { 'k' ,   ""         },    /* 	&#107;		Small k  */
+        { 'l' ,   ""         },    /* 	&#108;		Small l  */
+        { 'm' ,   ""         },    /* 	&#109;		Small m  */
+        { 'n' ,   ""         },    /* 	&#110;		Small n  */
+        { 'o' ,   ""         },    /* 	&#111;		Small o  */
+        { 'p' ,   ""         },    /* 	&#112;		Small p  */
+        { 'q' ,   ""         },    /* 	&#113;		Small q  */
+        { 'r' ,   ""         },    /* 	&#114;		Small r  */
+        { 's' ,   ""         },    /* 	&#115;		Small s  */
+        { 't' ,   ""         },    /* 	&#116;		Small t  */
+        { 'u' ,   ""         },    /* 	&#117;		Small u  */
+        { 'v' ,   ""         },    /* 	&#118;		Small v  */
+        { 'w' ,   ""         },    /* 	&#119;		Small w  */
+        { 'x' ,   ""         },    /* 	&#120;		Small x  */
+        { 'y' ,   ""         },    /* 	&#121;		Small y  */
+        { 'z' ,   ""         },    /* 	&#122;		Small z  */
+        { '{' ,   ""         },    /* 	&#123;		Left curly brace  */
+        { '|' ,   ""         },    /* 	&#124;		Vertical bar  */
+        { '}' ,   ""         },    /* 	&#125;		Right curly brace  */
+        { '~' ,   ""         },    /* 	&#126;		Tilde  */
+        { '' ,   ""         },    /* 	&#127;		Unused  */
+        { '' ,   ""         },    /* 	&#128;		Unused */
+        { ' ' ,   ""         },    /* &#129;		Unused  */
+        { ' ' ,   ""         },    /* &#130;		Unused  */
+        { ' ' ,   ""         },    /* &#131;		Unused  */
+        { ' ' ,   ""         },    /* &#132;		Unused  */
+        { ' ' ,   ""         },    /* &#133;		Unused  */
+        { ' ' ,   ""         },    /* &#134;		Unused  */
+        { ' ' ,   ""         },    /* &#135;		Unused  */
+        { ' ' ,   ""         },    /* &#136;		Unused  */
+        { ' ' ,   ""         },    /* &#137;		Unused  */
+        { ' ' ,   ""         },    /* &#138;		Horizontal tab  */
+        { ' ' ,   ""         },    /* &#139;		Line feed  */
+        { ' ' ,   ""         },    /* &#140;		Unused  */
+        { ' ' ,   ""         },    /* &#141;		Unused  */
+        { ' ' ,   ""         },    /* &#142;		Carriage Return  */
+        { ' ' ,   ""         },    /* &#143;		Unused  */
+        { ' ' ,   ""         },    /* &#144;		Unused  */
+        { ' ' ,   ""         },    /* &#145;		Unused  */
+        { ' ' ,   ""         },    /* &#146;		Unused  */
+        { ' ' ,   ""         },    /* &#147;		Unused  */
+        { ' ' ,   ""         },    /* &#148;		Unused  */
+        { ' ' ,   ""         },    /* &#149;		Unused  */
+        { ' ' ,   ""         },    /* &#150;		Unused  */
+        { ' ' ,   ""         },    /* &#151;		Unused  */
+        { ' ' ,   ""         },    /* &#152;		Unused  */
+        { ' ' ,   ""         },    /* &#153;		Unused  */
+        { ' ' ,   ""         },    /* &#154;		Unused  */
+        { ' ' ,   ""         },    /* &#155;		Unused  */
+        { ' ' ,   ""         },    /* &#156;		Unused  */
+        { ' ' ,   ""         },    /* &#157;		Unused  */
+        { ' ' ,   ""         },    /* &#158;		Unused  */
+        { ' ' ,   ""         },    /* &#159;		Unused  */
+        { ' ' ,   ""   },    /* 	Non-breaking Space  */
+        { '' ,   ""  },    /* 	Inverted exclamation    */
+        { '' ,   ""   },    /* 	Cent sign               */
+        { '' ,   ""  },    /* 	Pound sterling  */
+        { '' ,   "" },    /* 	General currency sign  */
+        { '' ,   ""    },    /* 	Yen sign  */
+/*        { '' ,   "" },    / *  	Broken vertical bar  */
+        { '' ,   "" },    /* 	Broken vertical bar  */
+        { '' ,   ""  },    /* 	Section sign  */
+/*        { '' ,   ""    },    / *  	Diresis / Umlaut  */
+        { '' ,   ""   },    /* 	Diresis / Umlaut  */
+        { '' ,   ""  },    /* 	Copyright               */
+        { '' ,   ""  },    /* 	Feminine ordinal  */
+        { '' ,   "" },    /* 	Left angle quote, guillemot left  */
+        { '' ,   ""   },    /*	Not sign  */
+        { '' ,   ""    },    /* 	Soft hyphen  */
+        { '' ,   ""    },    /* 	Registered trademark  */
+/*        { '' ,   ""   },    / *  	Macron accent  */
+        { '' ,   ""  },    /* 	Macron accent  */
+        { '' ,   ""    },    /* 	Degree sign  */
+        { '' ,   "" },    /* 	Plus or minus  */
+        { '' ,   ""   },    /* 	Superscript two  */
+        { '' ,   ""   },    /* 	Superscript three  */
+        { '' ,   ""  },    /* 	Acute accent  */
+        { '' ,   ""  },    /* 	Micro sign  */
+        { '' ,   ""   },    /* 	Paragraph sign  */
+        { '' ,   "" },    /* 	Middle dot  */
+        { '' ,   ""  },    /* 	Cedilla  */
+        { '' ,   ""   },    /* 	Superscript one  */
+        { '' ,   ""   },    /* 	Masculine ordinal  */
+        { '' ,   ""  },    /* 	Right angle quote, guillemot right  */
+        { '' ,   "" },    /* 	Fraction one-fourth  */
+        { '' ,   "" },    /* 	Fraction one-half  */
+        { '' ,   "" },    /* 	Fraction three-fourths  */
+        { '' ,   "" },    /* 	Inverted question mark  */
+        { '' ,   "" },    /* 	Capital A, grave accent  */
+        { '' ,   "" },    /* 	Capital A, acute accent  */
+        { '' ,   ""  },    /* 	Capital A, circumflex  */
+        { '' ,   "" },    /* 	Capital A, tilde  */
+        { '' ,   ""   },    /* 	Capital A, diresis / umlaut  */
+        { '' ,   ""  },    /* 	Capital A, ring  */
+        { '' ,   ""  },    /* 	Capital AE ligature  */
+        { '' ,   "" },    /* 	Capital C, cedilla  */
+        { '' ,   "" },    /* 	Capital E, grave accent  */
+        { '' ,   "" },    /* 	Capital E, acute accent  */
+        { '' ,   ""  },    /* 	Capital E, circumflex  */
+        { '' ,   ""   },    /* 	Capital E, diresis / umlaut  */
+        { '' ,   "" },    /* 	Capital I, grave accent  */
+        { '' ,   "" },    /* 	Capital I, acute accent  */
+        { '' ,   ""  },    /* 	Capital I, circumflex  */
+        { '' ,   ""   },    /* 	Capital I, diresis / umlaut  */
+        { '' ,   ""    },    /* 	Capital Eth, Icelandic  */
+        { '' ,   "" },    /* 	Capital N, tilde  */
+        { '' ,   "" },    /* 	Capital O, grave accent  */
+        { '' ,   "" },    /* 	Capital O, acute accent  */
+        { '' ,   ""  },    /* 	Capital O, circumflex  */
+        { '' ,   "" },    /* 	Capital O, tilde  */
+        { '' ,   ""   },    /* 	Capital O, diresis / umlaut  */
+        { '' ,   ""  },    /* 	Multiply sign  */
+        { '' ,   "" },    /* 	Capital O, slash  */
+        { '' ,   "" },    /* 	Capital U, grave accent  */
+        { '' ,   "" },    /* 	Capital U, acute accent  */
+        { '' ,   ""  },    /* 	Capital U, circumflex  */
+        { '' ,   ""   },    /* 	Capital U, diresis / umlaut  */
+        { '' ,   "" },    /* 	Capital Y, acute accent  */
+        { '' ,   ""  },    /* 	Capital Thorn, Icelandic  */
+        { '' ,   ""  },    /* 	Small sharp s, German sz  */
+        { '' ,   "" },    /* 	Small a, grave accent  */
+        { '' ,   "" },    /* 	Small a, acute accent  */
+        { '' ,   ""  },    /* 	Small a, circumflex  */
+        { '' ,   "" },    /* 	Small a, tilde  */
+        { '' ,   ""   },    /* 	Small a, diresis / umlaut  */
+        { '' ,   ""  },    /* 	Small a, ring  */
+        { '' ,   ""  },    /* 	Small ae ligature  */
+        { '' ,   "" },    /* 	Small c, cedilla  */
+        { '' ,   "" },    /* 	Small e, grave accent  */
+        { '' ,   "" },    /* 	Small e, acute accent  */
+        { '' ,   ""  },    /* 	Small e, circumflex  */
+        { '' ,   ""   },    /* 	Small e, diresis / umlaut  */
+        { '' ,   "" },    /* 	Small i, grave accent  */
+        { '' ,   "" },    /* 	Small i, acute accent  */
+        { '' ,   ""  },    /* 	Small i, circumflex  */
+        { '' ,   ""   },    /* 	Small i, diresis / umlaut  */
+        { '' ,   ""    },    /* 	Small eth, Icelandic  */
+        { '' ,   "" },    /* 	Small n, tilde  */
+        { '' ,   "" },    /* 	Small o, grave accent  */
+        { '' ,   "" },    /* 	Small o, acute accent  */
+        { '' ,   ""  },    /* 	Small o, circumflex  */
+        { '' ,   "" },    /* 	Small o, tilde  */
+        { '' ,   ""   },    /* 	Small o, diresis / umlaut  */
+        { '' ,   "" },    /* 	Division sign  */
+        { '' ,   "" },    /* 	Small o, slash  */
+        { '' ,   "" },    /* 	Small u, grave accent  */
+        { '' ,   "" },    /* 	Small u, acute accent  */
+        { '' ,   ""  },    /* 	Small u, circumflex  */
+        { '' ,   ""   },    /* 	Small u, diresis / umlaut  */
+        { '' ,   "" },    /* 	Small y, acute accent  */
+        { '' ,   ""  },    /* 	Small thorn, Icelandic  */
+        { '\255', ""   },    /* 	Small y, diresis / umlaut  */
+    } ; 
+ 
+struct tCharTrans Char2HtmlLatin2 [] = 
+
+    {
+        { ' ' ,   ""         },    /* &#00;		Unused */ 
+        { ' ' ,   ""         },    /* &#01;		Unused */
+        { ' ' ,   ""         },    /* &#02;		Unused  */
+        { ' ' ,   ""         },    /* &#03;		Unused  */
+        { ' ' ,   ""         },    /* &#04;		Unused  */
+        { ' ' ,   ""         },    /* &#05;		Unused  */
+        { ' ' ,   ""         },    /* &#06;		Unused  */
+        { ' ' ,   ""         },    /* &#07;		Unused  */
+        { ' ' ,   ""         },    /* &#08;		Unused  */
+        { ' ' ,   ""         },    /* &#09;		Horizontal tab  */
+        { ' ' ,   ""         },    /* &#10;		Line feed  */
+        { ' ' ,   ""         },    /* &#11;		Unused  */
+        { ' ' ,   ""         },    /* &#12;		Unused  */
+        { ' ' ,   ""         },    /* &#13;		Carriage Return  */
+        { ' ' ,   ""         },    /* &#14;		Unused  */
+        { ' ' ,   ""         },    /* &#15;		Unused  */
+        { ' ' ,   ""         },    /* &#16;		Unused  */
+        { ' ' ,   ""         },    /* &#17;		Unused  */
+        { ' ' ,   ""         },    /* &#18;		Unused  */
+        { ' ' ,   ""         },    /* &#19;		Unused  */
+        { ' ' ,   ""         },    /* &#20;		Unused  */
+        { ' ' ,   ""         },    /* &#21;		Unused  */
+        { ' ' ,   ""         },    /* &#22;		Unused  */
+        { ' ' ,   ""         },    /* &#23;		Unused  */
+        { ' ' ,   ""         },    /* &#24;		Unused  */
+        { ' ' ,   ""         },    /* &#25;		Unused  */
+        { ' ' ,   ""         },    /* &#26;		Unused  */
+        { ' ' ,   ""         },    /* &#27;		Unused  */
+        { ' ' ,   ""         },    /* &#28;		Unused  */
+        { ' ' ,   ""         },    /* &#29;		Unused  */
+        { ' ' ,   ""         },    /* &#30;		Unused  */
+        { ' ' ,   ""         },    /* &#31;		Unused  */
+        { ' ' ,   ""         },    /* 	&#32;		Space  */
+        { '!' ,   ""         },    /* 	&#33;		Exclamation mark  */
+        { '"' ,   "&quot;"   },    /* 	Quotation mark  */
+        { '#' ,   ""         },    /* 	&#35;		Number sign  */
+        { '$' ,   ""         },    /* 	&#36;		Dollar sign  */
+        { '%' ,   ""         },    /* 	&#37;		Percent sign  */
+        { '&' ,   "&amp;"    },    /* 	Ampersand  */
+        { '\'' ,  ""         },    /* 	&#39;		Apostrophe  */
+        { '(' ,   ""         },    /* 	&#40;		Left parenthesis  */
+        { ')' ,   ""         },    /* 	&#41;		Right parenthesis  */
+        { '*' ,   ""         },    /* 	&#42;		Asterisk  */
+        { '+' ,   ""         },    /* 	&#43;		Plus sign  */
+        { ',' ,   ""         },    /* 	&#44;		Comma  */
+        { '-' ,   ""         },    /* 	&#45;		Hyphen  */
+        { '.' ,   ""         },    /* 	&#46;		Period (fullstop)  */
+        { '/' ,   ""         },    /* 	&#47;		Solidus (slash)  */
+        { '0' ,   ""         },    /* 	&#48;		Digit 0  */
+        { '1' ,   ""         },    /* 	&#49;		Digit 1  */
+        { '2' ,   ""         },    /* 	&#50;		Digit 2  */
+        { '3' ,   ""         },    /* 	&#51;		Digit 3  */
+        { '4' ,   ""         },    /* 	&#52;		Digit 4  */
+        { '5' ,   ""         },    /* 	&#53;		Digit 5  */
+        { '6' ,   ""         },    /* 	&#54;		Digit 6  */
+        { '7' ,   ""         },    /* 	&#55;		Digit 7  */
+        { '8' ,   ""         },    /* 	&#56;		Digit 8  */
+        { '9' ,   ""         },    /* 	&#57;		Digit 9  */
+        { ':' ,   ""         },    /* 	&#58;		Colon  */
+        { ';' ,   ""         },    /* 	&#59;		Semicolon  */
+        { '<' ,   "&lt;"     },    /* 	Less than  */
+        { '=' ,   ""         },    /* 	&#61;		Equals sign  */
+        { '>' ,   "&gt;"     },    /* 	Greater than  */
+        { '?' ,   ""         },    /* 	&#63;		Question mark  */
+        { '@' ,   ""         },    /* 	&#64;		Commercial at  */
+        { 'A' ,   ""         },    /* 	&#65;		Capital A  */
+        { 'B' ,   ""         },    /* 	&#66;		Capital B  */
+        { 'C' ,   ""         },    /* 	&#67;		Capital C  */
+        { 'D' ,   ""         },    /* 	&#68;		Capital D  */
+        { 'E' ,   ""         },    /* 	&#69;		Capital E  */
+        { 'F' ,   ""         },    /* 	&#70;		Capital F  */
+        { 'G' ,   ""         },    /* 	&#71;		Capital G  */
+        { 'H' ,   ""         },    /* 	&#72;		Capital H  */
+        { 'I' ,   ""         },    /* 	&#73;		Capital I  */
+        { 'J' ,   ""         },    /* 	&#74;		Capital J  */
+        { 'K' ,   ""         },    /* 	&#75;		Capital K  */
+        { 'L' ,   ""         },    /* 	&#76;		Capital L  */
+        { 'M' ,   ""         },    /* 	&#77;		Capital M  */
+        { 'N' ,   ""         },    /* 	&#78;		Capital N  */
+        { 'O' ,   ""         },    /* 	&#79;		Capital O  */
+        { 'P' ,   ""         },    /* 	&#80;		Capital P  */
+        { 'Q' ,   ""         },    /* 	&#81;		Capital Q  */
+        { 'R' ,   ""         },    /* 	&#82;		Capital R  */
+        { 'S' ,   ""         },    /* 	&#83;		Capital S  */
+        { 'T' ,   ""         },    /* 	&#84;		Capital T  */
+        { 'U' ,   ""         },    /* 	&#85;		Capital U  */
+        { 'V' ,   ""         },    /* 	&#86;		Capital V  */
+        { 'W' ,   ""         },    /* 	&#87;		Capital W  */
+        { 'X' ,   ""         },    /* 	&#88;		Capital X  */
+        { 'Y' ,   ""         },    /* 	&#89;		Capital Y  */
+        { 'Z' ,   ""         },    /* 	&#90;		Capital Z  */
+        { '[' ,   ""         },    /* 	&#91;		Left square bracket  */
+        { '\\' ,  ""         },    /* 	&#92;		Reverse solidus (backslash)  */
+        { ']' ,   ""         },    /* 	&#93;		Right square bracket  */
+        { '^' ,   ""         },    /* 	&#94;		Caret  */
+        { '_' ,   ""         },    /* 	&#95;		Horizontal bar (underscore)  */
+        { '`' ,   ""         },    /* 	&#96;		Acute accent  */
+        { 'a' ,   ""         },    /* 	&#97;		Small a  */
+        { 'b' ,   ""         },    /* 	&#98;		Small b  */
+        { 'c' ,   ""         },    /* 	&#99;		Small c  */
+        { 'd' ,   ""         },    /* 	&#100;		Small d  */
+        { 'e' ,   ""         },    /* 	&#101;		Small e  */
+        { 'f' ,   ""         },    /* 	&#102;		Small f  */
+        { 'g' ,   ""         },    /* 	&#103;		Small g  */
+        { 'h' ,   ""         },    /* 	&#104;		Small h  */
+        { 'i' ,   ""         },    /* 	&#105;		Small i  */
+        { 'j' ,   ""         },    /* 	&#106;		Small j  */
+        { 'k' ,   ""         },    /* 	&#107;		Small k  */
+        { 'l' ,   ""         },    /* 	&#108;		Small l  */
+        { 'm' ,   ""         },    /* 	&#109;		Small m  */
+        { 'n' ,   ""         },    /* 	&#110;		Small n  */
+        { 'o' ,   ""         },    /* 	&#111;		Small o  */
+        { 'p' ,   ""         },    /* 	&#112;		Small p  */
+        { 'q' ,   ""         },    /* 	&#113;		Small q  */
+        { 'r' ,   ""         },    /* 	&#114;		Small r  */
+        { 's' ,   ""         },    /* 	&#115;		Small s  */
+        { 't' ,   ""         },    /* 	&#116;		Small t  */
+        { 'u' ,   ""         },    /* 	&#117;		Small u  */
+        { 'v' ,   ""         },    /* 	&#118;		Small v  */
+        { 'w' ,   ""         },    /* 	&#119;		Small w  */
+        { 'x' ,   ""         },    /* 	&#120;		Small x  */
+        { 'y' ,   ""         },    /* 	&#121;		Small y  */
+        { 'z' ,   ""         },    /* 	&#122;		Small z  */
+        { '{' ,   ""         },    /* 	&#123;		Left curly brace  */
+        { '|' ,   ""         },    /* 	&#124;		Vertical bar  */
+        { '}' ,   ""         },    /* 	&#125;		Right curly brace  */
+        { '~' ,   ""         },    /* 	&#126;		Tilde  */
+        { '' ,   ""         },    /* 	&#127;		Unused  */
+        { '' ,   ""         },    /* 	&#128;		Unused */
+         
+        { ' ' ,   ""         },    /* &#129;		Unused  */
+        { ' ' ,   ""         },    /* &#130;		Unused  */
+        { ' ' ,   ""         },    /* &#131;		Unused  */
+        { ' ' ,   ""         },    /* &#132;		Unused  */
+        { ' ' ,   ""         },    /* &#133;		Unused  */
+        { ' ' ,   ""         },    /* &#134;		Unused  */
+        { ' ' ,   ""         },    /* &#135;		Unused  */
+        { ' ' ,   ""         },    /* &#136;		Unused  */
+        { ' ' ,   ""         },    /* &#137;		Unused  */
+        { ' ' ,   ""         },    /* &#138;		Horizontal tab  */
+        { ' ' ,   ""         },    /* &#139;		Line feed  */
+        { ' ' ,   ""         },    /* &#140;		Unused  */
+        { ' ' ,   ""         },    /* &#141;		Unused  */
+        { ' ' ,   ""         },    /* &#142;		Carriage Return  */
+        { ' ' ,   ""         },    /* &#143;		Unused  */
+        { ' ' ,   ""         },    /* &#144;		Unused  */
+        { ' ' ,   ""         },    /* &#145;		Unused  */
+        { ' ' ,   ""         },    /* &#146;		Unused  */
+        { ' ' ,   ""         },    /* &#147;		Unused  */
+        { ' ' ,   ""         },    /* &#148;		Unused  */
+        { ' ' ,   ""         },    /* &#149;		Unused  */
+        { ' ' ,   ""         },    /* &#150;		Unused  */
+        { ' ' ,   ""         },    /* &#151;		Unused  */
+        { ' ' ,   ""         },    /* &#152;		Unused  */
+        { ' ' ,   ""         },    /* &#153;		Unused  */
+        { ' ' ,   ""         },    /* &#154;		Unused  */
+        { ' ' ,   ""         },    /* &#155;		Unused  */
+        { ' ' ,   ""         },    /* &#156;		Unused  */
+        { ' ' ,   ""         },    /* &#157;		Unused  */
+        { ' ' ,   ""         },    /* &#158;		Unused  */
+        { ' ' ,   ""         },    /* &#159;		Unused  */
+        { ' ', "&nbsp;" },             /* &#160; - nobreakspace */
+        { '',  "" },           /* &#161; - Aogonek */
+        { '',  "" },           /* &#162; - breve */
+        { '',  "" },           /* &#163; - Lstroke */
+        { '',  "&curren;" },           /* &#164; - currency */
+        { '',  "" },           /* &#165; - Lcaron */
+        { '',  "" },           /* &#166; - Sacute */
+        { '',  "&sect;" },             /* &#167; - section */
+        { '',  "&die;" },              /* &#168; - diaeresis */
+        { '',  "" },           /* &#169; - Scaron */
+        { '',  "" },           /* &#170; - Scedilla */
+        { '',  "" },           /* &#171; - Tcaron */
+        { '',  "" },           /* &#172; - Zacute */
+        { '',  "&shy;" },              /* &#173; - hyphen */
+        { '',  "" },           /* &#174; - Zcaron */
+        { '',  "" },           /* &#175; - Zabovedot */
+        { '',  "&degree;" },           /* &#176; - degree */
+        { '',  "" },           /* &#177; - aogonek */
+        { '',  "" },           /* &#178; - ogonek */
+        { '',  "" },           /* &#179; - lstroke */
+        { '',  "&acute;" },            /* &#180; - acute */
+        { '',  "" },           /* &#181; - lcaron */
+        { '',  "" },           /* &#182; - sacute */
+        { '',  "" },           /* &#183; - caron */
+        { '',  "&Cedilla;" },          /* &#184; - cedilla */
+        { '',  "" },           /* &#185; - scaron */
+        { '',  "" },           /* &#186; - scedilla */
+        { '',  "" },           /* &#187; - tcaron */
+        { '',  "" },           /* &#188; - zacute */
+        { '',  "" },           /* &#189; - doubleacute */
+        { '',  "" },           /* &#190; - zcaron */
+        { '',  "" },           /* &#191; - zabovedot */
+        { '',  "" },           /* &#192; - Racute */
+        { '',  "&Aacute;" },           /* &#193; - Aacute */
+        { '',  "&Acirc;" },            /* &#194; - Acircumflex */
+        { '',  "" },           /* &#195; - Abreve */
+        { '',  "&Auml;" },             /* &#196; - Adiaeresis */
+        { '',  "" },           /* &#197; - Lacute */
+        { '',  "" },           /* &#198; - Cacute */
+        { '',  "&Ccedil;" },           /* &#199; - Ccedilla */
+        { '',  "" },           /* &#200; - Ccaron */
+        { '',  "&Eacute;" },           /* &#201; - Eacute */
+        { '',  "" },           /* &#202; - Eogonek */
+        { '',  "&Euml;" },             /* &#203; - Ediaeresis */
+        { '',  "" },           /* &#204; - Ecaron */
+        { '',  "&Iacute;" },           /* &#205; - Iacute */
+        { '',  "&Icirc;" },            /* &#206; - Icircumflex */
+        { '',  "" },           /* &#207; - Dcaron */
+        { '',  "&ETH;" },              /* &#208; - Eth */
+        { '',  "" },           /* &#209; - Nacute */
+        { '',  "" },           /* &#210; - Ncaron */
+        { '',  "&Oacute;" },           /* &#211; - Oacute */
+        { '',  "&Ocirc;" },            /* &#212; - Ocircumflex */
+        { '',  "" },           /* &#213; - Odoubleacute */
+        { '',  "&Ouml;" },             /* &#214; - Odiaeresis */
+        { '',  "&times;" },            /* &#215; - multiply */
+        { '',  "" },           /* &#216; - Rcaron */
+        { '',  "" },           /* &#217; - Uring */
+        { '',  "&Uacute;" },           /* &#218; - Uacute */
+        { '',  "" },           /* &#219; - Udoubleacute */
+        { '',  "&Uuml;" },             /* &#220; - Udiaeresis */
+        { '',  "&Yacute;" },           /* &#221; - Yacute */
+        { '',  "" },           /* &#222; - Tcedilla */
+        { '',  "&szlig;" },            /* &#223; - ssharp */
+        { '',  "" },           /* &#224; - racute */
+        { '',  "&aacute;" },           /* &#225; - aacute */
+        { '',  "&acirc;" },            /* &#226; - acircumflex */
+        { '',  "" },           /* &#227; - abreve */
+        { '',  "&auml;" },             /* &#228; - adiaeresis */
+        { '',  "" },           /* &#229; - lacute */
+        { '',  "" },           /* &#230; - cacute */
+        { '',  "&ccedil;" },           /* &#231; - ccedilla */
+        { '',  "" },           /* &#232; - ccaron */
+        { '',  "&eacute;" },           /* &#233; - eacute */
+        { '',  "" },           /* &#234; - eogonek */
+        { '',  "&euml;" },             /* &#235; - ediaeresis */
+        { '',  "" },           /* &#236; - ecaron */
+        { '',  "&iacute;" },           /* &#237; - iacute */
+        { '',  "&icirc;" },            /* &#238; - icircumflex */
+        { '',  "" },           /* &#239; - dcaron */
+        { '',  "&eth;" },              /* &#240; - eth */
+        { '',  "" },           /* &#241; - nacute */
+        { '',  "" },           /* &#242; - ncaron */
+        { '',  "&oacute;" },           /* &#243; - oacute */
+        { '',  "&ocirc;" },            /* &#244; - ocircumflex */
+        { '',  "" },           /* &#245; - odoubleacute */
+        { '',  "&ouml;" },             /* &#246; - odiaeresis */
+        { '',  "&divide;" },           /* &#247; - division */
+        { '',  "" },           /* &#248; - rcaron */
+        { '',  "" },           /* &#249; - uring */
+        { '',  "&uacute;" },           /* &#250; - uacute */
+        { '',  "" },           /* &#251; - udoubleacute */
+        { '',  "&uuml;" },             /* &#252; - udiaeresis */
+        { '',  "&yacute;" },           /* &#253; - yacute */
+        { '',  "" },           /* &#254; - tcedilla */
+        { '\255',  "" },           /* &#255; - abovedot */
+    } ; 
+ 
  
 
 struct tCharTrans Char2Url [] = 
